[![codecov](https://codecov.io/gh/DAtek/datek-agar-core/branch/master/graph/badge.svg?token=YYOA2LGHS2)](https://codecov.io/gh/DAtek/datek-agar-core)
<a href="https://github.com/psf/black"><img alt="Code style: black" src="https://img.shields.io/badge/code%20style-black-000000.svg"></a>
<a href="https://github.com/psf/black/blob/main/LICENSE"><img alt="License: MIT" src="https://black.readthedocs.io/en/stable/_static/license.svg"></a>

# Agar game core

The project contains the game logic, the rules of this universe, the server and an async client.
It's in early stage of development.


## Installation
If your OS is compatible with `uvloop`, install it with `pip install datek-agar-core[uvloop]`


## Usage
After installing, just type `run-server` in the terminal.
For help, type `run-server --help`
